==> kftpgrabber-trinity-14.0.6.tar.xz: kftpgrabber-trinity-14.0.6/kftpgrabber/src/widgets/listview.cpp <==
/*
 * This file is part of the KFTPGrabber project
 *
 * Copyright (C) 2003-2004 by the KFTPGrabber developers
 * Copyright (C) 2003-2004 Jernej Kos <kostko@jweb-network.net>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * is provided AS IS, WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, and
 * NON-INFRINGEMENT.  See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Steet, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */

#include "listview.h"

#include <ntqpainter.h>
#include <ntqstringlist.h>

namespace KFTPWidgets {

ListView::ListView(TQWidget *parent, const char *name)
 : TDEListView(parent, name)
{
}


ListView::~ListView()
{
}

void ListView::resizeEvent(TQResizeEvent *e)
{
  TDEListView::resizeEvent(e);
  triggerUpdate();
}

void ListView::setEmptyListText(const TQString &text)
{
  m_emptyListText = text;
  triggerUpdate();
}

void ListView::drawContentsOffset(TQPainter * p, int ox, int oy, int cx, int cy, int cw, int ch)
{
  TDEListView::drawContentsOffset(p, ox, oy, cx, cy, cw, ch);

  if (childCount() == 0 && !m_emptyListText.isEmpty()) {
    p->setPen(TQt::darkGray);

    TQStringList lines = TQStringList::split("\n", m_emptyListText);
    int ypos = 10 + p->fontMetrics().height();

    TQStringList::Iterator end(lines.end());
    for (TQStringList::Iterator str( lines.begin() ); str != end; ++str) {
      p->drawText((viewport()->width()/2)-(p->fontMetrics().width(*str)/2), ypos, *str);
      ypos += p->fontMetrics().lineSpacing();
    }
  }
}

}

#include "listview.moc"

==> kftpgrabber-trinity-14.0.12.tar.xz: kftpgrabber-trinity-14.0.12/kftpgrabber/src/widgets/listview.cpp <==
/*
 * This file is part of the KFTPGrabber project
 *
 * Copyright (C) 2003-2004 by the KFTPGrabber developers
 * Copyright (C) 2003-2004 Jernej Kos <kostko@jweb-network.net>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * is provided AS IS, WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, and
 * NON-INFRINGEMENT.  See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Steet, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */

#include "listview.h"

#include <tqpainter.h>
#include <tqstringlist.h>

namespace KFTPWidgets {

ListView::ListView(TQWidget *parent, const char *name)
 : TDEListView(parent, name)
{
}


ListView::~ListView()
{
}

void ListView::resizeEvent(TQResizeEvent *e)
{
  TDEListView::resizeEvent(e);
  triggerUpdate();
}

void ListView::setEmptyListText(const TQString &text)
{
  m_emptyListText = text;
  triggerUpdate();
}

void ListView::drawContentsOffset(TQPainter * p, int ox, int oy, int cx, int cy, int cw, int ch)
{
  TDEListView::drawContentsOffset(p, ox, oy, cx, cy, cw, ch);

  if (childCount() == 0 && !m_emptyListText.isEmpty()) {
    p->setPen(TQt::darkGray);

    TQStringList lines = TQStringList::split("\n", m_emptyListText);
    int ypos = 10 + p->fontMetrics().height();

    TQStringList::Iterator end(lines.end());
    for (TQStringList::Iterator str( lines.begin() ); str != end; ++str) {
      p->drawText((viewport()->width()/2)-(p->fontMetrics().width(*str)/2), ypos, *str);
      ypos += p->fontMetrics().lineSpacing();
    }
  }
}

}

#include "listview.moc"
